.. autosummary::
   :toctree: _autosummary
   :template: custom-module-template.rst
   :recursive:

   bec_lib
   bec_client
   scan_server
   scan_bundler
   device_server
   file_writer
   scihub
   data_processing